filter_dataset_after_time: Filter Tabular Dataset with time stamp columns after a...

View source: R/datasets.R

filter_dataset_after_timeR Documentation

Filter Tabular Dataset with time stamp columns after a specified start time.

Description

Filter Tabular Dataset with time stamp columns after a specified start time.

Usage

filter_dataset_after_time(dataset, start_time, include_boundary = TRUE)

Arguments

dataset

The Tabular Dataset object

start_time

The lower bound for filtering data.

include_boundary

Boolean indicating if the row associated with the boundary time (start_time) should be included.

Value

The filtered Tabular Dataset


Azure/azureml-sdk-for-r documentation built on Sept. 21, 2022, 5:45 a.m.