filter_dataset_before_time: Filter Tabular Dataset with time stamp columns before a...

View source: R/datasets.R

filter_dataset_before_timeR Documentation

Filter Tabular Dataset with time stamp columns before a specified end time.

Description

Filter Tabular Dataset with time stamp columns before a specified end time.

Usage

filter_dataset_before_time(dataset, end_time, include_boundary = TRUE)

Arguments

dataset

The Tabular Dataset object

end_time

The upper bound for filtering data.

include_boundary

Boolean indicating if the row associated with the boundary time (start_time) should be included.

Value

The filtered Tabular Dataset


Azure/azureml-sdk-for-r documentation built on Sept. 21, 2022, 5:45 a.m.